@@ -16,7 +16,7 @@ class List:
         if isinstance(value, self.type):
             self.contents.append(value)
         else:
-            Terminal.error(f"Type mismatch:{type(value)} is not {type}")
+            Terminal.error(f"Type mismatch:{type(value)} is not {self.type}")
             raise TypeError
 
     def extend(self, iterator):
@@ -48,4 +48,4 @@ class List:
             text += i + spacer
         text = text.removesuffix(spacer)
         text += "]"
-        return text
+        return text
\ No newline at end of file
